@@ -186,7 +186,6 @@ type tcMocks struct {
 	appBuilder            *builder.MockComponentBuilder
 	appDockerEngineClient *builder.MockDockerEngineClient
 	oauth                 *domocks.MockOAuthService
-	tokens                *domocks.MockTokensService
 }
 
 func withTestClient(t *testing.T, tFn testFn) {
@@ -232,7 +231,6 @@ func withTestClient(t *testing.T, tFn testFn) {
 		appBuilder:            builder.NewMockComponentBuilder(ctrl),
 		appDockerEngineClient: builder.NewMockDockerEngineClient(ctrl),
 		oauth:                 domocks.NewMockOAuthService(ctrl),
-		tokens:                domocks.NewMockTokensService(ctrl),
 	}
 
 	testConfig := doctl.NewTestConfig()
@@ -287,7 +285,6 @@ func withTestClient(t *testing.T, tFn testFn) {
 		Monitoring:        func() do.MonitoringService { return tm.monitoring },
 		Serverless:        func() do.ServerlessService { return tm.serverless },
 		OAuth:             func() do.OAuthService { return tm.oauth },
-		Tokens:            func() do.TokensService { return tm.tokens },
 	}
 
 	tFn(config, tm)
